/* Error constants for TPF.
   Copyright (C) 2003 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */

#ifndef _ERRNO_H                                                                //ZTPF11
# error "Never use <bits/errno.h> directly; include <errno.h> instead."         //ZTPF11
#else                                                                           //ZTPF11

/*****************************************************************/
/* Note: This file was originally promoted from                  */
/*          glibc/sysdeps/unix/sysv/tpf/bits/errno.h             */
/*****************************************************************/

/* errno is a per-thread variable and is referenced */
/* through the __tpf_errno_location() function.     */
#include <bits/thruvars.h>                                                      //ZTPF11
#define  errno  (*__tpf_errno_location())                                       //ZTPF11

#if defined _LIBC                                                               //ZTPF11
/* Define __set_errno for the sake of glibc */
#define __set_errno(val)   errno = (val)                                        //ZTPF11
#endif                                                                          //ZTPF11

/******************************************************************************/
/* Standard system errno values and TPF-specific errno values are defined     */
/* after this comment block.                                                  */
/*                                                                            */
/* Errno numbers 5000-7000 are reserved for TPF use only and are coded in     */
/*   file.                                                                    */
/* Errno numbers 9000-11000 are reserved for customer use and are coded in    */
/*   bits/errnu.h.                                                            */
/******************************************************************************/

  /*  added for BSD vfs port support                              */
  #ifdef KERNEL                                                                 //ZTPF11
    /* pseudo-error returned inside kernel to modify return to process */
    #define ERESTART -1       /* restart syscall */                             //ZTPF11
    #define EJUSTRETURN -2    /* don't modify regs, just return */              //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ESUCCESS                                                              //ZTPF11
    #define ESUCCESS      0    /* Useful result for cat, cp, mv, chmod etc. */  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EDOM                                                                  //ZTPF11
    #define EDOM         33    /* Math argument out of domain of function.  */  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ERANGE                                                                //ZTPF11
    #define ERANGE       34    /* Math result not representable.  */            //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EWOULDBLOCK         /* BSDTPF ADDED ? */                              //ZTPF11
    #define EWOULDBLOCK  35                                                     //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENOMSG                                                                //ZTPF11
    #define ENOMSG       42   /* No message of desired type */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ECANCELED                                                             //ZTPF11
    #define ECANCELED    47   /* Operation canceled */                          //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ETIMEDOUT                                                             //ZTPF11
    #define ETIMEDOUT    60   /* BSDTPF ADDED ? */                              //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ECONNREFUSED                                                          //ZTPF11
    #define ECONNREFUSED 61   /* BSDTPF ADDED ? */                              //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ELOOP                                                                 //ZTPF11
    #define ELOOP        62   /* A loop exists in symbolic  */                  //ZTPF11
                              /* links encountered during   */
                              /* resolution of the path     */
                              /* argument                   */
  #endif                                                                        //ZTPF11

  #ifndef ENAMETOOLONG                                                          //ZTPF11
    #define ENAMETOOLONG 63   /* Filename too long          */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENOTEMPTY                                                             //ZTPF11
    #define ENOTEMPTY    66   /* Directory not empty        */                  //ZTPF11
  #endif                                                                        //ZTPF11
  #ifndef EDQUOT
    #define EDQUOT       69   /* Disc quota exceeded */
  #endif

  #ifndef EOVERFLOW                                                             //ZTPF11
    #define EOVERFLOW    75   /* Data Type overflow */                          //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EFTYPE                                                                //ZTPF11
    #define EFTYPE       79   /* Inappropriate file type or format */           //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EILSEQ                                                                //ZTPF11
    #define EILSEQ       84   /* Illegal byte sequence.  */                     //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EACCES                                                                //ZTPF11
    #define EACCES      111   /* Permission denied          */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EAGAIN                                                                //ZTPF11
    #define EAGAIN      112   /* Resource Temporarily unavailable */            //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EBADF                                                                 //ZTPF11
    #define EBADF       113   /* Bad file descriptor            */              //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EBUSY                                                                 //ZTPF11
    #define EBUSY       114   /* Resource busy              */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ECHILD                                                                //ZTPF11
    #define ECHILD      115   /* No child processes         */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EDEADLK                                                               //ZTPF11
    #define EDEADLK     116   /* Resource deadlock avoided  */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EEXIST                                                                //ZTPF11
    #define EEXIST      117   /* File exists                */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EFAULT                                                                //ZTPF11
    #define EFAULT      118   /* Bad address                */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EFBIG                                                                 //ZTPF11
    #define EFBIG       119   /* File too large             */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EINTR                                                                 //ZTPF11
    #define EINTR       120   /* Interrupted function call  */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EINVAL                                                                //ZTPF11
    #define EINVAL      121   /* Invalid argument               */              //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EIO                                                                   //ZTPF11
    #define EIO         122   /* Input/output error         */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EISDIR                                                                //ZTPF11
    #define EISDIR      123   /* Is a directory             */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EMFILE                                                                //ZTPF11
    #define EMFILE      124   /* Too many open file descriptors */              //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EMLINK                                                                //ZTPF11
    #define EMLINK      125   /* Too many links             */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENFILE                                                                //ZTPF11
    #define ENFILE      127   /* Too many open files in the system */           //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENODEV                                                                //ZTPF11
    #define ENODEV      128   /* No such device             */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENOENT                                                                //ZTPF11
    #define ENOENT      129   /* No such file or directory  */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENOEXEC                                                               //ZTPF11
    #define ENOEXEC     130   /* Exec format error          */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENOLCK                                                                //ZTPF11
   #define ENOLCK       131   /* No locks available         */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENOMEM                                                                //ZTPF11
    #define ENOMEM      132   /* Not enough space           */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENOSPC                                                                //ZTPF11
    #define ENOSPC      133   /* No space left on device    */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENOSYS                                                                //ZTPF11
    #define ENOSYS      134   /* Function not implemented   */                  //ZTPF11
    #define EOPNOTSUPP  134   /* Operation not supported    */                  //ZTPF11
    #define ENOTSUP EOPNOTSUPP                                                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENOTDIR                                                               //ZTPF11
    #define ENOTDIR     135   /* Not a directory            */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENOTTY                                                                //ZTPF11
    #define ENOTTY      137   /* Inappropriate I/O control operation */         //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ENXIO                                                                 //ZTPF11
    #define ENXIO       138   /* No such device or address  */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EPERM                                                                 //ZTPF11
    #define EPERM       139   /* Operation not permitted    */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EPIPE                                                                 //ZTPF11
    #define EPIPE       140   /* Broken pipe                */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EROFS                                                                 //ZTPF11
    #define EROFS       141   /* Read-only file system      */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ESPIPE                                                                //ZTPF11
    #define ESPIPE      142   /* Invalid seek               */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef ESRCH                                                                 //ZTPF11
    #define ESRCH       143   /* No such process            */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EXDEV                                                                 //ZTPF11
    #define EXDEV       144   /* A link to a file on another*/                  //ZTPF11
                              /* file system was attempted  */
  #endif                                                                        //ZTPF11

  #ifndef E2BIG                                                                 //ZTPF11
    #define E2BIG       145   /* Arg list too long          */                  //ZTPF11
  #endif                                                                        //ZTPF11

  #ifndef EMAXTHD                                                               //ZTPF11
    #define EMAXTHD     148   /* Max number of threads per process is reached *///ZTPF11
         /*NOTE: EMAXTHD is not used for the POSIX 1003.1c thread API */
  #endif                                                                        //ZTPF11

  #ifndef ESTALE                                                                //ZTPF11
    #define ESTALE      150   /* Stale file handle */                           //ZTPF11
  #endif                                                                        //ZTPF11

  #define EMVSTODNOTSET 165   /* System TOD clock not set   */                  //ZTPF11

  #define ETPFSYSERR    501   /* Child process terminated abnormally*/          //ZTPF11
                              /* because of system error.           */

  #ifndef ETXTBSY                                                               //ZTPF11
    #define ETXTBSY    1101   /* Text file busy */                              //ZTPF11
  #endif                                                                        //ZTPF11

/******************************************************************************/
/* Start of TPF-specific errno values.  Errno values must be in the range     */
/* 5000-7000 and must have a "ETPF" prefix.                                   */
/******************************************************************************/

  #define ETPFFSNOTRDY 5001     /* A TPF file system service was      */        //ZTPF11
                                /* requested before the file system   */
                                /* was usable.                        */

  #define ETPFWRONGSS  5002     /* The file descriptor is not valid   */        //ZTPF11
                                /* in the current subsystem           */

  #define ETPFCOMITER  5003     /* Comit/Rollback error has been      */        //ZTPF11
                                /* received                           */

  #define ETPFSOCKERR  5004     /* I/O error on socket accessed       */        //ZTPF11
                                /* accessed through file descriptor   */

  #define ETPFNODDN    5005     /* zdsmg ddname definition not        */        //ZTPF11
                                /* found                              */

  #define ETPFNPIPWSYS 5010     /* Attempt to access Named Pipe from  */        //ZTPF11
                                /* system other than the one it was   */
                                /* created on.                        */

  #define ETPFGSYS_INVTKN  5011 /* GSYSC- INVALID TOKEN ADDR        */          //ZTPF11

  #define ETPFGSYS_INVOWNR 5012 /* GSYSC- INVALID OWNER ADDR        */          //ZTPF11

  #define ETPFGSYS_NUNQTKN 5013 /* GSYSC- NON-UNIQUE TOKEN          */          //ZTPF11

  #define ETPFGSYS_NOMEM   5014 /* GSYSC- NO CONTIGUOUS MEMRY       */          //ZTPF11

  #define ETPFGSYS_INVFRMS 5015 /* GSYSC- INVALID NBR FRAMES        */          //ZTPF11

  #define ETPFRSYS_INVTKN  5016 /* RSYSC- INVALID TOKEN ADDR        */          //ZTPF11

  #define ETPFRSYS_TKNNFND 5017 /* RSYSC- UNIQUE TOKEN              */          //ZTPF11
                                /*        NOT FOUND                 */

  #define ETPFRSYS_TKNMMTCH 5018 /* RSYSC- TOKEN MISMATCH           */          //ZTPF11

  #define ETPFRSYS_INVADDR 5019 /* RSYSC- SYS HEAP ADDR ERROR       */          //ZTPF11

  #define ETPFRSYS_ADDRNUSD 5020 /* RSYSC- SYS HEAP ADDRRSS         */          //ZTPF11
                                 /*        NOT IN USE               */

  #define ETPFRSYS_INVFRMS 5021 /* RSYSC- INVALID NBR FRAMES        */          //ZTPF11

  #define ETPFFSYS_INVTKN  5022 /* FSYSC- INVALID TOKEN ADDR        */          //ZTPF11

  #define ETPFFSYS_TKNNFND 5023 /* FSYSC- UNIQUE TOKEN              */          //ZTPF11
                                /*        NOT FOUND                 */


  /******************************************************************/
  /*   5031 through 5050 are reserved for Format-2 Globals Support  */
  /******************************************************************/
  #define ETPFGLOB_BADNAME 5031 /* Bad Format-2 global name         */          //ZTPF11
  #define ETPFGLOB_BADADDR 5032 /* Address specified on Format-2    */          //ZTPF11
                                /* globals API was NULL             */
  #define ETPFGLOB_OPEN    5033 /* Format-2 global is already open  */          //ZTPF11
  #define ETPFGLOB_BADOPTIONS 5034                                              //ZTPF11
                                /* Options specified for this       */
                                /* Format-2 globals API call are    */
                                /* not valid                        */
  #define ETPFGLOB_BADDESC 5035 /* Format-2 global descriptor       */          //ZTPF11
                                /* specified is not valid           */
  #define ETPFGLOB_READONLY 5036                                                //ZTPF11
                                /* Format-2 global was opened for   */
                                /* read-only, no updates are allowed*/
  #define ETPFGLOB_BADOFFSET 5037                                               //ZTPF11
                                /* Format-2 global API specified an */
                                /* offset into the global that was  */
                                /* not valid                        */
  #define ETPFGLOB_BADLENGTH 5038                                               //ZTPF11
                                /* Format-2 global API specified a  */
                                /* length for the global that was   */
                                /* not valid                        */
  #define ETPFGLOB_NOUPDATES 5039                                               //ZTPF11
                                /* Format-2 global API requested an */
                                /* update to a global that is not   */
                                /* keypointable or synchronizable   */
  #define ETPFGLOB_UNINIT 5040  /* Format-2 global specified has    */          //ZTPF11
                                /* not yet been initialized         */
  #define ETPFGLOB_NOHEAP 5041  /* Insufficient ECB heap storage    */          //ZTPF11
                                /* available to create Format-2     */
                                /* global descriptor                */
  #define ETPFGLOB_REINIT 5042  /* Format-2 global specified has    */          //ZTPF11
                                /* been reinitialized, no further   */
                                /* actions are allowed              */
  #define ETPFGLOB_DELETED 5043 /* Format-2 global specified has    */          //ZTPF11
                                /* been deleted, no further actions */
                                /* are allowed                      */
  #define ETPFGLOB_TIMEOUT 5044 /* Format-2 global update did not   */          //ZTPF11
                                /* complete within the 3-minute     */
                                /* timeout period                   */
  /****End of Format-2 Globals errno values**************************/


  #define ETPFMOVE_BADFR 5051 /* A call to MOVEC was made with      */          //ZTPF11
                              /* a bad address in the range from the*/
                              /* from parm to the from parm plus the*/
                              /* length parm.                       */

  #define ETPFMOVE_BADTO 5052 /* A call to MOVEC was made with      */          //ZTPF11
                              /* a bad address in the range from the*/
                              /* to parm to the to parm plus the    */
                              /* length parm.                       */

  #define ETPFLODIC_LOWRES  5053   /* LODIC errno */                            //ZTPF11

  #define ETPFLODIC_MAXSUSP 5054   /* LODIC errno */                            //ZTPF11
/*                                                                  */
/* 5055, 5056, 5057 errno values reserved for future LODIC use      */
/*                                                                  */

  #define ETPFLODIC_NOTFOUND 5058  /* LODIC errno */                            //ZTPF11

  /******************************************************************/
  /* Errno values 5061-5090 reserved for owners support apis such as*/
  /* tpf_eownrc(), tpf_ownerc(), and their corresponding macros.    */
  /******************************************************************/

  /******************************************************************/
  /* tpf_eownrc() and EOWNRC macro errno values.                    */
  /******************************************************************/

  /* An address was supplied for the owner parameter that was not   */
  /* tpf_eownrc().                                                  */
  #define ETPF_EOWNRC_OWNER_ERR   5061                                          //ZTPF11

  /* An incorrect function was requested (not TPF_GET_EOWNR,        */
  /* TPF_SET_EOWNR or TPF_ADDRESS_EOWNR) on tpf_eownrc().           */
  #define ETPF_EOWNRC_FUNC_ERR    5062                                          //ZTPF11

  /******************************************************************/
  /* tpf_ownerc() and OWNERC macro errno values.                    */
  /******************************************************************/

  /*   ownerc macro processing was unable to allocate required 64-bit */
  /*   system heap storage.                                           */
  #define ETPF_OWNERC_SYSHEAP_ERR  5068                                         //ZTPF11

  /* A blank owner name or owner name of a single wildcard character*/
  /* was supplied (both C api and macro).                           */
  #define ETPF_OWNERC_OWNER_NAME_ERR    5069                                    //ZTPF11

  /* A pointer to owner name information was supplied that was not  */
  /* an addressable storage location (both C api and macro).        */
  #define ETPF_OWNERC_OWNER_ADDRESS_ERR 5070                                    //ZTPF11

  /* An incorrect block type was specified for the blktype parameter*/
  /* on tpf_ownerc().                                               */
  #define ETPF_OWNERC_BLKTYPE_ERR 5071                                          //ZTPF11

  /* A count was specified for the high parameter which was less    */
  /* zero (both C api and macro).                                   */
  #define ETPF_OWNERC_BADHIGH_ERR 5072                                          //ZTPF11

  /* A count was specified for the high parameter which exceeded    */
  /* the maximum value allowed (both C api and macro).              */
  #define ETPF_OWNERC_MAXHIGH_ERR 5073                                          //ZTPF11

  /* OWNERC macro processing was unable to allocate required ECB    */
  /* heap storage (both C api and macro).                           */
  #define ETPF_OWNERC_ECBHEAP_ERR 5074                                          //ZTPF11

  /* OWNERC macro processing detected incorrect use of wildcard     */
  /* character '*' in owner name (both C api and macro).            */
  #define ETPF_OWNERC_WILDCARD_ERR 5075                                         //ZTPF11

  /* tpf_ownerc() processing detected BLOCK=ALL with no owner name  */
  /* supplied.                                                      */
  #define ETPF_OWNERC_NO_OWNER_ALL_ERR 5076                                     //ZTPF11

  /* tpf_ownerc() processing supplied area pointer of NULL.         */
  #define ETPF_OWNERC_AREA_ERR         5077                                     //ZTPF11

  /****End of errno values for owners support************************/

/********************************************************************/
/*     5120 through 5150 are reserved for HTTP Client support.      */
/********************************************************************/
  #define ETPFHTTP_HANDLEERR    5120
                                /* Handle specified for HTTP client */
                                /* API was not valid.               */
  #define ETPFHTTP_LIBERR       5121
                                /* HTTP client attempted to set an  */
                                /* unsupported option in the        */
                                /* underlying HTTP protocol library */
  #define ETPFHTTP_NOHEAP       5122
                                /* There is not enough ECB heap to  */
                                /* process the HTTP client request  */
  #define ETPFHTTP_UHHI         5123
                                /* Error returned from UHHI user    */
                                /* exit                             */
  #define ETPFHTTP_UHPR         5124
                                /* Error returned from UHPR user    */
                                /* exit                             */
  #define ETPFHTTP_UHPO         5125
                                /* Error returned from UHPO user    */
                                /* exit                             */
  #define ETPFHTTP_NETRCERR     5126
                                /* .netrc file specified for HTTP   */
                                /* Client API was not valid.        */
  #define ETPFHTTP_NOHTTPC      5127
                                /* There is no HTTP Client loaded   */
  #define ETPFHTTP_PROTOERR     5128
                                /* HTTP Protocol error, not HTTP or */
                                /* HTTPS.                           */
  #define ETPFHTTP_SSLCFGERR    5129
                                /* SSL configuration file for HTTP  */
                                /* client support is in error       */
  #define ETPFHTTP_HOSTERR      5130
                                /* Remote host specified for HTTP   */
                                /* client API was not valid         */
  #define ETPFHTTP_CONNERR      5131
                                /* Error connecting to remote HTTP  */
                                /* server                           */
  #define ETPFHTTP_NOACCESS     5132
                                /* User is not allowed to access the*/
                                /* specified directory or file on   */
                                /* the remote HTTP server           */
  #define ETPFHTTP_SSLERR       5133
                                /* There was an error creating a    */
                                /* secure HTTP client session       */
  #define ETPFHTTP_INTERR       5134
                                /* An internal error occurred while */
                                /* processing the specified HTTP    */
                                /* client API                       */
  #define ETPFHTTP_SERVERR      5135
                                /* An error occurred on the remote  */
                                /* HTTP server                      */
  #define ETPFHTTP_TIMEOUT      5136
                                /* HTTP client operation timed out  */
  #define ETPFHTTP_INVAL        5137
                                /* A HTTP client parameter in not   */
                                /* valid.                           */
  #define ETPFHTTP_NOSYSHEAP    5138
                                /* There is not enough system heap  */
                                /* to process the HTTP client       */
                                /* request                          */
  #define ETPFHTTP_NODAEMON     5139
                                /* The HTTP client daemon is not    */
                                /* active                           */
  #define ETPFHTTP_QUEUEMAX     5140
                                /* One of the HTTP client daemon's  */
                                /* queues has already reached its   */
                                /* maximum length                   */
  #define ETPFHTTP_INTDAEMON    5141
                                /* An internal error occurred in    */
                                /* the HTTP client daemon           */
  #define ETPFHTTP_NOTABLE      5142
                                /* One of the system heap tables    */
                                /* that is needed to process the    */
                                /* request could not be found.      */
 #define ETPFHTTP_MOVECERR      5143
                                /* An error occured during movec so */
                                /* the response data can't be passed*/
                                /* to the user application          */
 #define ETPFHTTP_UHSP          5144
                                /* uhsp_httpDaemonSelectProc user   */
                                /* exit returned an error           */
 #define ETPFHTTP_UHSPNOPROC    5145
                                /* uhsp_httpDaemonSelectProc user   */
                                /* exit removed all processes from  */
                                /* selection                        */

/****End of errno values for HTTP Client support*********************/

/********************************************************************/
/*     5151 through 5184 are reserved for FTP Client support.       */
/********************************************************************/
  #define ETPFFTP_HOSTERR       5151
                                /* Remote host specified for FTP    */
                                /* client API was not valid         */
  #define ETPFFTP_CONNERR       5152
                                /* Error connecting to remote FTP   */
                                /* server                           */
  #define ETPFFTP_LIMITERR      5153
                                /* Maximum number of active FTP     */
                                /* client sessions has beeen reached*/
  #define ETPFFTP_PASSERR       5154
                                /* Password specified for remote    */
                                /* FTP server is not correct        */
  #define ETPFFTP_NOACCESS      5155
                                /* User is not allowed to access the*/
                                /* specified directory or file on   */
                                /* the remote FTP server            */
  #define ETPFFTP_NOHEAP        5156
                                /* There is not enough ECB heap to  */
                                /* process the FTP client request   */
  #define ETPFFTP_NETRCERR      5157
                                /* The .netrc file specified is not */
                                /* valid                            */
  #define ETPFFTP_SSLERR        5158
                                /* There was an error creating a    */
                                /* secure FTP client session        */
  #define ETPFFTP_INTERR        5159
                                /* An internal error occurred while */
                                /* processing the specified FTP     */
                                /* client API                       */
  #define ETPFFTP_SERVERR       5160
                                /* An error occurred on the remote  */
                                /* FTP server                       */
  #define ETPFFTP_BADSESSID     5161
                                /* The FTP client session ID        */
                                /* specified was not valid          */
  #define ETPFFTP_WRITEERR      5162
                                /* Error writing received file out  */
                                /* to the TPF file system           */
  #define ETPFFTP_RETRERR       5163
                                /* Error occurred while attempting  */
                                /* to retrieve the file from the    */
                                /* remote FTP server                */
  #define ETPFFTP_SIZEERR       5164
                                /* Size of the retrieved file does  */
                                /* not match the expected size      */
  #define ETPFFTP_TIMEOUT       5165
                                /* FTP client operation timed out   */
  #define ETPFFTP_BADOPTS       5166
                                /* Options specified on the FTP     */
                                /* client API are not valid         */
  #define ETPFFTP_READERR       5167
                                /* Error reading file from TPF file */
                                /* system                           */
  #define ETPFFTP_STORERR       5168
                                /* Error storing file on remote FTP */
                                /* server                           */
  #define ETPFFTP_NOTCPC        5169
                                /* TCP/IP configuration table does  */
                                /* not exist                        */
  #define ETPFFTP_NOFTPC        5170
                                /* FTP client support is disabled   */
  #define ETPFFTP_NOGFS         5171
                                /* GFS support is not active        */
  #define ETPFFTP_PROFERR       5172
                                /* FTP client profile is in error   */
  #define ETPFFTP_NOPROF        5173
                                /* FTP client profile does not exist*/
  #define ETPFFTP_DISCONN       5174
                                /* FTP client session has been      */
                                /* disconnected                     */
  #define ETPFFTP_ABORTED       5175
                                /* FTP client transfer has been     */
                                /* aborted by the operator          */
  #define ETPFFTP_SSLCFGERR     5176
                                /* SSL configuration file for FTP   */
                                /* client support is in error       */
  #define ETPFFTP_TRANSDISC     5177
                                /* FTP client transfer completed    */
                                /* successfully, but session was    */
                                /* disconnected due to operator     */
                                /* request                          */
  #define ETPFFTP_LIBERR        5178
                                /* FTP client attempted to set an   */
                                /* unsupported option in the        */
                                /* underlying FTP protocol library  */
  #define ETPFFTP_NODIR         5179
                                /* FTP client attempted to download */
                                /* a file from a remote FTP server  */
                                /* into a directory that doesn't    */
                                /* exist                            */


/********************************************************************/
/*   5185 through 5190 are reserved for tpf_SSL_getConfig() API     */
/********************************************************************/
  #define ETPFSSL_BADAPP        5185
                                /* Application name specified does  */
                                /* not referece a valid SSL         */
                                /* configuration application        */
  #define ETPFSSL_BADQUAL       5186
                                /* Application qualifier specified  */
                                /* does not reference a valid SSL   */
                                /* configuration for the specified  */
                                /* application                      */
  #define ETPFSSL_READERR       5187
                                /* Error reading in indicated SSL   */
                                /* configuration file               */
  #define ETPFSSL_HEAPERR       5188
                                /* Not enough ECB heap to satisfy   */
                                /* tpf_SSL_getConfig request        */
  #define ETPFSSL_CONFERR       5189
                                /* The SSL configuration file       */
                                /* indicated is not in a valid      */
                                /* format                           */
  #define ETPFSSL_UXERR         5190
                                /* The SSL configuration file user  */
                                /* exit (USCF) returned an error    */

/********************************************************************/

  #define ETPFSNOTENABLED       5200  /* Security not enabled.      */

/********************************************************************/
/*  5201 - 5210 Reserved for tpf_pageprot_storage() API             */
/********************************************************************/
#define ETPF_PAGEPROT_STORAGE_ERR  5201
                                /* Target adddresses not backed     */
                                /* with real storage.               */

#define ETPF_PAGEPROT_AREA_ERR     5202
                                /* Storage area specified in CPLKC  */
                                /* FUNCTION=VIRT_SVC is not valid   */

#define ETPF_PAGEPROT_FUNC_ERR     5203
                                /* Requested function is not valid  */

#define ETPF_PAGEPROT_STORAGE_START_ERR 5204
                                /* Incorrect starting storage       */
                                /* address (not in valid area or    */
                                /* not on a 4KB boundary).          */

#define ETPF_PAGEPROT_STORAGE_LEN_ERR   5205
                                /* Incorrect storage size (0 or     */
                                /* greater than 524288).            */

#define ETPF_PAGEPROT_STORAGE_END_ERR   5206
                                /* End of requested storage does    */
                                /* not reside in a valid area       */
/********************************************************************/

/********************************************************************/
/*     5220 through 5250 are reserved for TPF SOAP support.         */
/********************************************************************/
  #define ETPFSOAP_NOHEAP             5220
                                /* There is not enough ECB heap to  */
                                /* process the request              */
  #define ETPFSOAP_NOSERVICE          5221
                                /* The service specified does not   */
                                /* exist or is not deployed         */
  #define ETPFSOAP_HANDLEERR          5222
                                /* Handle specified for SOAP        */
                                /* consumer API was not valid.      */
  #define ETPFSOAP_INVAL              5223
                                /* Invalid options for SOAP         */
                                /* consumer API.                    */
  #define ETPFSOAP_INDEXERR           5224
                                /* Invalid index specified.         */
  #define ETPFSOAP_TRANSPORTERR       5225
                                /* Invalid transport specified.     */
  #define ETPFSOAP_UWSI               5226
                                /* Error returned from UWSI UE      */
  #define ETPFSOAP_UWSE               5227
                                /* Error returned from UWSE UE      */
  #define ETPFSOAP_UWST               5228
                                /* Error returned from UWST UE      */
  #define ETPFSOAP_MEP_NOT_SUPPORTED  5229
                                /* Incorrect MEP was specified      */
  #define ETPFSOAP_SOAP_FAULT         5230
                                /* SOAP fault message returned      */
  #define ETPFSOAP_HTTPERR            5231
                                /* HTTP transport error             */
  #define ETPFSOAP_TPFTOTPFERR        5232
                                /* TPF-to-TPF transport error       */
  #define ETPFSOAP_MQERR              5233
                                /* MQ transport error               */
  #define ETPFSOAP_USERERR            5234
                                /* User transport error             */
  #define ETPFSOAP_STUBERR_REQ        5235
                                /* Error returned from the stub     */
                                /* request                          */
  #define ETPFSOAP_MSG_HANDLERERR_REQ 5236
                                /* Error returned from message      */
                                /* handler(s) request               */
  #define ETPFSOAP_TIMEOUT            5237
                                /* Request timed out                */
  #define ETPFSOAP_TRANSLATEERR       5238
                                /* Error during translation         */
  #define ETPFSOAP_XML_HANDLEERR      5239
                                /* No XML handle to retrieve        */
  #define ETPFSOAP_XML_APIERR         5240
                                /* Error from xml api's             */
  #define ETPFSOAP_SYNTAXERR          5241
                                /* Invalid soap syntax              */
  #define ETPFSOAP_HTTPSRVRERR        5242
                                /* HTTP server-side error           */
  #define ETPFSOAP_STUBERR_RESP       5243
                                /* Error returned from the stub     */
                                /* response                         */
  #define ETPFSOAP_MSG_HANDLERERR_RESP 5244
                                /* Error returned from message      */
                                /* handler(s) response              */
  #define ETPFSOAP_LENGTHERR           5245
                                /* Maximum length exceeded on a     */
                                /* parameter string                 */
  #define ETPFSOAP_NOT_UNDERSTAND      5246
                                /* mustUnderstand is set to true,   */
                                /* but consumer does not understand */
                                /* the header(s)                    */

/* Use 5300-5399 for XML Encryption. */
#define EXMLENC_INVALID_ELEMENT      5300
                              /* Function cannot operate on       */
                              /* current element.                 */
#define EXMLENC_INVALID_NAMESPACE        5301
#define EXMLENC_TYPE_REQUIRED            5302
#define EXMLENC_ENCRYP_METHOD_REQUIRED   5303
#define EXMLENC_CIPHERDATA_REQUIRED      5304
#define EXMLENC_CIPHERVALUE_REQUIRED     5305
#define EXMLENC_KEYINFO_NOTPRESENT       5306
#define EXMLENC_UNKNOWN_KEYALGORITHM     5307
#define EXMLENC_DATA_DECRYP_FAILED       5308
#define EXMLENC_DATA_TRANSLATION_FAILED  5309
#define EXMLENC_KEY_DECRYP_FAILED        5310
#define EXMLENC_AMBIGIOUS_KEYINFO        5311
#define EXMLENC_BASE64_CONVERT_FAILED    5312
#define EXMLENC_KEYHANDLE_REQUIRED       5313
#define EXMLENC_REFERENCE_LIST_NOTFOUND  5314
#define EXMLENC_DATA_ENCRYP_FAILED       5315
#define EXMLENC_INVALID_ENCRYPTION_TYPE  5316
#define EXMLENC_INVALID_ENCRYPTION_ID    5317
#define EXMLENC_INVALID_KEYNAME          5318

#define EXMLENC_MANIFEST_OR_KEY_HANDLE_REQUIRED  5319
#define EXMLENC_ONLY_ONE_HANDLE_ACCEPTED 5320
#define EXMLENC_ELEMENT_MISSING_ID       5321
#define EXMLENC_DUPLICATE_ELEMENTS       5322
#define EXMLENC_MANIFEST_URI_REFERENCE_NOTFOUND  5323
#define EXMLENC_TYPE_NOT_RECOGNIZED      5324
#define EXMLENC_SERVER_NDSP_ERROR        5325
#define EXMLENC_CLIENT_ID_MISSING        5326
#define EXMLENC_INVALID_KEY_ALIAS        5327

/* Use 5400-5499 for XPATH. */
#define EXPATH_INVALIDATED               5400
#define EXPATH_INVALID_EXPRESSION        5401
#define EWSSE_EXTFILE_NOTBUILT           5500
#define EWSSE_EXTFILE_NOTFOUND           5501
#define EWSSE_EXTFILE_NOTSPECIFIED       5502
#define EWSSE_XML4C_INIT_ERROR           5503
#define EWSSE_EXTFILE_NOTVALID           5504

/* Use 5600-5699 for ZTPF HTTP SERVER - ASYNC SOAP */
#define ETPF_HTTPSENDRSP_TOKEN_ERR               5600
   /* Input token was NULL or was not a valid value  */ 

#define ETPF_HTTPSENDRSP_CONNECTION_CLOSED       5601
   /* Client connection associated with input token has been closed. */

#define ETPF_HTTPSENDRSP_REQUEST_TIMEOUT         5602
   /* The zTPF system has timed out the HTTP request associated
      with this response. */

#define ETPF_HTTPSENDRSP_RESPONSE_ERR            5603
   /* The input pointer to the HTTP response structure was NULL
      or was not pointing to addressable storage */

#define ETPF_HTTPSENDRSP_MALLOC_ERR              5604
   /* API processing was unable to allocate malloc() storage to
      send the response message */

#define ETPF_HTTPSENDRSP_SOCKET_ERR              5605
   /* An error occurred when attempting to send the response over
      the associated client connection.  */

#define ETPF_SOAPRETRIEVECTX_TOKEN_ERR           5606 
   /* Input token was NULL or was not a valid value */

#define ETPF_SOAPRETRIEVECTX_BUFFER_ERR          5607 
   /* The input pointer to the context buffer save area was NULL 
      or was not pointing to addressable storage */

#define ETPF_SOAPRETRIEVECTX_TIMEOUT             5608
   /* The asynchronous SOAP sweeper has timed out the SOAP request 
      associated with this token. */

#define ETPF_SOAPSAVECTX_BUFFER_ERR              5609 
   /* The input pointer to the context buffer save area was NULL
      or was not pointing to addressable storage */

#define ETPF_SOAPSAVECTX_SYSTEM_HEAP_ERR         5610
   /* API processing was unable to allocate system heap storage to
      save the SOAP message context information */

#define ETPF_SOAPSENDRSP_BUFFER_ERR              5611 
   /* The input pointer to the SOAP message context buffer was NUL
      or was not pointing to addressable storage */

#define ETPF_SOAPTPFHTTP_SCART_ERR               5612
   /* SCART entry was not found */
   
#define ETPF_SOAPSENDRSP_SENDCOMMS_ERR           5613
   /* The response was not sent by zTPF HTTP server     */

#define ETPF_SOAPTPFHTTP_INVALID_BINDING_TYPE    5614
   /* The zTPF comms binding received invalid 
      binding type - not tpf_HTTP      */

#define ETPF_HTTPSENDRSP_VERSION_ERR             5615
   /* HTTP version in response structure was not valid. */

#define ETPF_HTTPSENDRSP_STATUS_ERR              5616
   /* Status code in HTTP response structure was not valid. */

#define ETPF_HTTPSENDRSP_SYNTAX_ERR              5617
   /* Text passed in the HTTP response structure was not valid. */

/* Include any customer-specific errno values */
#include <bits/errnu.h>                                                         //ZTPF11

/* Include more tpf-specific errno values */
#if defined _TPF_SOURCE
#include <tpf/errno.h>                                                      
#endif
 
#endif                                                                          //ZTPF11
